==> react-date-primitives-0.4.1.tgz: package/esm/components/DateRangeControl.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { startOfMonth, addMonths, isDayBefore, callIfExists } from './utils';
/**
 * Controller component for making a date-range picker in conjunction with [CalendarMonth]()
 */
var DateRangeControl = /** @class */ (function (_super) {
    __extends(DateRangeControl, _super);
    function DateRangeControl(props) {
        var _this = _super.call(this, props) || this;
        _this.handleDayClick = function (day) {
            _this.setState(function (state) {
                var startDate = state.startDate, selectionActive = state.selectionActive;
                var newState;
                if (startDate && selectionActive && !isDayBefore(day, startDate)) {
                    newState = {
                        startDate: startDate,
                        endDate: day
                    };
                    callIfExists(_this.props.onDatesChange, newState);
                    return __assign({ selectionActive: false }, newState);
                }
                newState = {
                    startDate: day,
                    endDate: undefined
                };
                callIfExists(_this.props.onDatesChange, newState);
                return __assign({ selectionActive: true }, newState);
            });
        };
        _this.handleDayHover = function (day) {
            var _a = _this.state, selectionActive = _a.selectionActive, startDate = _a.startDate;
            if (selectionActive && startDate && !isDayBefore(day, startDate)) {
                _this.setState(function () { return ({
                    endDate: day
                }); });
            }
        };
        _this.handleNavigation = function (months) { return function () {
            _this.setState(function (state) {
                return {
                    months: state.months.map(function (month) { return addMonths(month, months); })
                };
            });
        }; };
        var startDate = props.startDate, endDate = props.endDate, showThreeMonths = props.showThreeMonths;
        _this.numOfMonths = showThreeMonths ? 3 : 2;
        var thisMonth = startOfMonth(new Date());
        _this.state = {
            startDate: startDate,
            endDate: endDate,
            months: Array.from({ length: _this.numOfMonths }, function (_, i) {
                return addMonths(startDate || thisMonth, i);
            }),
            selectionActive: false
        };
        return _this;
    }
    DateRangeControl.prototype.componentWillReceiveProps = function (nextProps) {
        var _this = this;
        var startDate = nextProps.startDate, endDate = nextProps.endDate;
        this.setState(function (state) {
            return __assign({}, state, { startDate: startDate,
                endDate: endDate, months: Array.from({ length: _this.numOfMonths }, function (_, i) {
                    return addMonths(startDate || state.months[0], i);
                }) });
        });
    };
    DateRangeControl.prototype.render = function () {
        var _a = this.props, render = _a.render, minDate = _a.minDate, maxDate = _a.maxDate;
        var _b = this.state, months = _b.months, startDate = _b.startDate, endDate = _b.endDate;
        return render({
            months: months,
            startDate: startDate,
            endDate: endDate,
            minDate: minDate,
            maxDate: maxDate,
            onDayClick: this.handleDayClick,
            onDayHover: this.handleDayHover,
            moveForward: this.handleNavigation(1),
            moveBackward: this.handleNavigation(-1)
        });
    };
    return DateRangeControl;
}(React.Component));
export { DateRangeControl };

==> react-date-primitives-0.6.0.tgz: package/esm/components/DateRangeControl.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { startOfMonth, addMonths, isDayBefore, callIfExists } from '../utils';
/**
 * Controller component for making a date-range picker in conjunction with [CalendarMonth]()
 */
var DateRangeControl = /** @class */ (function (_super) {
    __extends(DateRangeControl, _super);
    function DateRangeControl(props) {
        var _this = _super.call(this, props) || this;
        _this.handleDayClick = function (day) {
            _this.setState(function (state) {
                var startDate = state.startDate, selectionActive = state.selectionActive;
                var newState;
                if (startDate && selectionActive && !isDayBefore(day, startDate)) {
                    newState = {
                        startDate: startDate,
                        endDate: day
                    };
                    callIfExists(_this.props.onDatesChange, newState);
                    return __assign({ selectionActive: false }, newState);
                }
                newState = {
                    startDate: day,
                    endDate: undefined
                };
                callIfExists(_this.props.onDatesChange, newState);
                return __assign({ selectionActive: true }, newState);
            });
        };
        _this.handleDayHover = function (day) {
            var _a = _this.state, selectionActive = _a.selectionActive, startDate = _a.startDate;
            if (selectionActive && startDate && !isDayBefore(day, startDate)) {
                _this.setState(function () { return ({
                    endDate: day
                }); });
            }
        };
        _this.handleNavigation = function (months) { return function () {
            _this.setState(function (state) {
                return {
                    months: state.months.map(function (month) { return addMonths(month, months); })
                };
            });
        }; };
        var startDate = props.startDate, endDate = props.endDate, showThreeMonths = props.showThreeMonths;
        _this.numOfMonths = showThreeMonths ? 3 : 2;
        var thisMonth = startOfMonth(new Date());
        _this.state = {
            startDate: startDate,
            endDate: endDate,
            months: Array.from({ length: _this.numOfMonths }, function (_, i) {
                return addMonths(startDate || thisMonth, i);
            }),
            selectionActive: false
        };
        return _this;
    }
    DateRangeControl.prototype.componentWillReceiveProps = function (nextProps) {
        var _this = this;
        var startDate = nextProps.startDate, endDate = nextProps.endDate;
        this.setState(function (state) {
            return __assign({}, state, { startDate: startDate,
                endDate: endDate, months: Array.from({ length: _this.numOfMonths }, function (_, i) {
                    return addMonths(startDate || state.months[0], i);
                }) });
        });
    };
    DateRangeControl.prototype.render = function () {
        var _a = this.props, render = _a.render, minDate = _a.minDate, maxDate = _a.maxDate;
        var _b = this.state, months = _b.months, startDate = _b.startDate, endDate = _b.endDate;
        return render({
            months: months,
            startDate: startDate,
            endDate: endDate,
            minDate: minDate,
            maxDate: maxDate,
            onDayClick: this.handleDayClick,
            onDayHover: this.handleDayHover,
            moveForward: this.handleNavigation(1),
            moveBackward: this.handleNavigation(-1)
        });
    };
    return DateRangeControl;
}(React.Component));
export { DateRangeControl };
